#!/bin/sh
#Firewall-status
#rcrsn51 2012-06-30
#radky 2013-06-30 and 2015-01-15, modified for PupControl
#radky 2015-10-20, add support for firewall_ng

[ "`whoami`" != "root" ] && exec sudo -A ${0} ${@}

export TEXTDOMAIN=firewallstatus
export OUTPUT_CHARSET=UTF-8

CURRDPI=`grep "^Xft\\.dpi:" $HOME/.Xresources 2>/dev/null | tr '\t' ' ' | tr -s ' ' | cut -f 2 -d ' '`
if [ "$CURRDPI" -gt "96" ]; then
  BOX1="12 48"
  BOX2="16 64"
else
  BOX1="10 46"
  BOX2="14 58"
fi

#check if firewall installed
if [ "`which firewall_ng`" ]; then
  if [ ! -f /etc/init.d/rc.firewall ]; then
    REPLY=`Xdialog --stdout --title " /etc/init.d/rc.firewall " --no-tags --no-cancel --radiolist "$(gettext 'Firewall is NOT installed')" $BOX1 2  "1" "$(gettext 'Install firewall')" "on"  "2" "$(gettext 'Do not install')" "off" `
    if [ "$REPLY" = "1" ]; then
      firewall_ng
      chmod 755 /etc/init.d/rc.firewall 
      exit 0
    elif [ "$REPLY" = "2" ]; then
      exit 0
    else
      exit 1
    fi
  fi
elif [ "`which firewallinstallshell`" ]; then
  if [ ! -f /etc/rc.d/rc.firewall ]; then
    REPLY=`Xdialog --stdout --title " /etc/rc.d/rc.firewall " --no-tags --no-cancel --radiolist "$(gettext 'Firewall is NOT installed')" $BOX1 2  "1" "$(gettext 'Install firewall')" "on"  "2" "$(gettext 'Do not install')" "off" `
    if [ "$REPLY" = "1" ]; then
      rxvt -e firewallinstallshell &
      exit 0
    elif [ "$REPLY" = "2" ]; then
      exit 0
    else
      exit 1
    fi
  fi
fi

#turn firewall on/off
if [ "`which firewall_ng`" ]; then
 if [ -f /etc/init.d/rc.firewall ]; then
   if [ "`iptables -L -n | wc -l`" -gt 10 ]; then
    REPLY=`Xdialog --stdout --title " /etc/init.d/rc.firewall " --no-tags --no-cancel --radiolist "$(gettext 'Firewall is ON')" $BOX1 2  "1" "$(gettext 'ON')" "on"  "2" "$(gettext 'Turn the firewall OFF')" "off" `
     if [ "$REPLY" = "1" ]; then
       continue
     elif [ "$REPLY" = "2" ]; then
       chmod +x /etc/init.d/rc.firewall
       /etc/init.d/rc.firewall stop
     else
       exit 1
     fi
   else 
     REPLY=`Xdialog --stdout --title " /etc/init.d/rc.firewall " --no-tags --no-cancel --radiolist "$(gettext 'Firewall is OFF')" $BOX1 2  "1" "$(gettext 'OFF')" "on"  "2" "$(gettext 'Turn the firewall ON')" "off" `
     if [ "$REPLY" = "1" ]; then
       continue
     elif [ "$REPLY" = "2" ]; then
       chmod +x /etc/init.d/rc.firewall
       /etc/init.d/rc.firewall start
     else
       exit 1
     fi
   fi
 fi
elif [ "`which firewallinstallshell`" ]; then
 if [ -f /etc/rc.d/rc.firewall ]; then
   if [ "`lsmod | grep iptable`" ]; then
     REPLY=`Xdialog --stdout --title " /etc/rc.d/rc.firewall " --no-tags --no-cancel --radiolist "$(gettext 'Firewall is ON')" $BOX1 2  "1" "$(gettext 'ON')" "on"  "2" "$(gettext 'Turn the firewall OFF')" "off" `
     if [ "$REPLY" = "1" ]; then
       continue
     elif [ "$REPLY" = "2" ]; then
       chmod +x /etc/rc.d/rc.firewall
       sh /etc/rc.d/rc.firewall stop
     else
       exit 1
     fi
   else 
     REPLY=`Xdialog --stdout --title " /etc/rc.d/rc.firewall " --no-tags --no-cancel --radiolist "$(gettext 'Firewall is OFF')" $BOX1 2  "1" "$(gettext 'OFF')" "on"  "2" "$(gettext 'Turn the firewall ON')" "off" `
     if [ "$REPLY" = "1" ]; then
       continue
     elif [ "$REPLY" = "2" ]; then
       chmod +x /etc/rc.d/rc.firewall
       sh /etc/rc.d/rc.firewall start
     else
       exit 1
     fi
   fi
 fi
fi

#start (or not start) at bootup
if [ "`which firewall_ng`" ]; then
  if [ -x /etc/init.d/rc.firewall ]; then
    START=""
    OPTION1="chmod +x /etc/init.d/rc.firewall"
    OPTION2="chmod -x /etc/init.d/rc.firewall"
    REPLY=`Xdialog --stdout --title " /etc/init.d/rc.firewall " --no-tags --no-cancel --radiolist "$(gettext 'Firewall is set to') $START $(gettext 'start at bootup')" $BOX2 3  "1" "$(gettext 'Start at bootup')" "on"  "2" "$(gettext 'Do NOT start at bootup')" "off" "3" "$(gettext 'Permanently remove the firewall
 (You can easily re-install it later)')" "off" `
  else
    START="$(gettext 'NOT')"
    OPTION1="chmod -x /etc/init.d/rc.firewall"
    OPTION2="chmod +x /etc/init.d/rc.firewall"
    REPLY=`Xdialog --stdout --title " /etc/init.d/rc.firewall " --no-tags --no-cancel --radiolist "$(gettext 'Firewall is set to') $START $(gettext 'start at bootup')" $BOX2 3  "1" "$(gettext 'Do NOT start at bootup')" "on"  "2" "$(gettext 'Start at bootup')" "off" "3" "$(gettext 'Permanently remove the firewall
 (You can easily re-install it later)')" "off" `
  fi
  [ $? -gt 0 ] && exit 1
  case "$REPLY" in
  1) $OPTION1;;
  2) $OPTION2;;
  3) Xdialog --title " /etc/rc.d/rc.firewall " --ok-label "$(gettext 'Yes')" --cancel-label "$(gettext 'No')" --yesno "\n  $(gettext 'Do you really want to remove the firewall?')  \n" 0 0
     if [ $? -eq 0 ]; then
       /etc/init.d/rc.firewall stop
       rm /etc/init.d/rc.firewall
     fi;;
  esac
  Xdialog --title " " --no-buttons --infobox "\n  $(gettext 'Please wait, saving...')\n" 0 0 2000
elif [ "`which firewallinstallshell`" ]; then
  if [ -x /etc/rc.d/rc.firewall ]; then
    START=""
    OPTION1="chmod +x /etc/rc.d/rc.firewall"
    OPTION2="chmod -x /etc/rc.d/rc.firewall"
    REPLY=`Xdialog --stdout --title " /etc/rc.d/rc.firewall " --no-tags --no-cancel --radiolist "$(gettext 'Firewall is set to') $START $(gettext 'start at bootup')" $BOX2 3  "1" "$(gettext 'Start at bootup')" "on"  "2" "$(gettext 'Do NOT start at bootup')" "off" "3" "$(gettext 'Permanently remove the firewall
 (You can easily re-install it later)')" "off" `
  else
    START="$(gettext 'NOT')"
    OPTION1="chmod -x /etc/rc.d/rc.firewall"
    OPTION2="chmod +x /etc/rc.d/rc.firewall"
    REPLY=`Xdialog --stdout --title " /etc/rc.d/rc.firewall " --no-tags --no-cancel --radiolist "$(gettext 'Firewall is set to') $START $(gettext 'start at bootup')" $BOX2 3  "1" "$(gettext 'Do NOT start at bootup')" "on"  "2" "$(gettext 'Start at bootup')" "off" "3" "$(gettext 'Permanently remove the firewall
 (You can easily re-install it later)')" "off" `
  fi
  [ $? -gt 0 ] && exit 1
  case "$REPLY" in
  1) $OPTION1;;
  2) $OPTION2;;
  3) Xdialog --title " /etc/rc.d/rc.firewall " --ok-label "$(gettext 'Yes')" --cancel-label "$(gettext 'No')" --yesno "\n  $(gettext 'Do you really want to remove the firewall?')  \n" 0 0
     if [ $? -eq 0 ]; then
       sh /etc/rc.d/rc.firewall stop
       rm /etc/rc.d/rc.firewall
     fi;;
  esac
  Xdialog --title " " --no-buttons --infobox "\n  $(gettext 'Please wait, saving...')\n" 0 0 2000
fi
